@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 The LaunchPad manages the FireWorks database.
 """
@@ -474,7 +472,7 @@ class LaunchPad(FWSerializable):
             {'fw_id': fw_id, 'state': {'$in': allowed_states}},
             {'$set': {'state': 'DEFUSED', 'updated_on': datetime.datetime.utcnow()}})
 
-        self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+        self._refresh_wf(fw_id)
         return f
 
     def reignite_fw(self, fw_id):
@@ -482,7 +480,7 @@ class LaunchPad(FWSerializable):
                                            {'$set': {'state': 'WAITING',
                                                      'updated_on': datetime.datetime.utcnow()}})
         if f:
-            self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+            self._refresh_wf(fw_id)
         return f
 
     def defuse_wf(self, fw_id):
@@ -490,7 +488,7 @@ class LaunchPad(FWSerializable):
         for fw in wf.fws:
             self.defuse_fw(fw.fw_id)
 
-        self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+        self._refresh_wf(fw_id)
 
     def reignite_wf(self, fw_id):
         wf = self.get_wf_by_fw_id(fw_id)
@@ -512,7 +510,7 @@ class LaunchPad(FWSerializable):
                                                {'$set': {'state': 'ARCHIVED',
                                                          'updated_on': datetime.datetime.utcnow()}})
 
-            self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+            self._refresh_wf(fw_id)
 
     def _restart_ids(self, next_fw_id, next_launch_id):
         """
@@ -535,8 +533,7 @@ class LaunchPad(FWSerializable):
             return True
 
         self._upsert_fws([m_fw])  # update the DB with the new launches
-        self._refresh_wf(self.get_wf_by_fw_id(m_fw.fw_id),
-                         m_fw.fw_id)  # since we updated a state, we need to refresh the WF again
+        self._refresh_wf(m_fw.fw_id)  # since we updated a state, we need to refresh the WF again
 
         return False
 
@@ -650,9 +647,7 @@ class LaunchPad(FWSerializable):
         self.launches.find_and_modify({'launch_id': m_launch.launch_id}, m_launch.to_db_dict(), upsert=True)
 
         for fw_data in self.fireworks.find({'launches': launch_id}, {'fw_id': 1}):
-            fw_id = fw_data['fw_id']
-            wf = self.get_wf_by_fw_id(fw_id)
-            self._refresh_wf(wf, fw_id)
+            self._refresh_wf(fw_data['fw_id'])
 
     def detect_lostruns(self, expiration_secs=RUN_EXPIRATION_SECS, fizzle=False, rerun=False, max_runtime=None, min_runtime=None):
         lost_launch_ids = []
@@ -785,8 +780,7 @@ class LaunchPad(FWSerializable):
         # find all the fws that have this launch
         for fw in self.fireworks.find({'launches': launch_id}, {'fw_id': 1}):
             fw_id = fw['fw_id']
-            with WFLock(self, fw_id):
-                self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+            self._refresh_wf(fw_id)
         # change return type to dict to make return type seriazlizable to
         # support job packing
         return m_launch.to_dict()
@@ -864,20 +858,23 @@ class LaunchPad(FWSerializable):
 
         return reruns  # return the ids that were rerun
 
-    def _refresh_wf(self, wf, fw_id):
+    def _refresh_wf(self, fw_id):
 
         """
         Update the FW state of all jobs in workflow
-        :param wf: a Workflow object
         :param fw_id: the parent fw_id - children will be refreshed
         """
         # TODO: time how long it took to refresh the WF!
         # TODO: need a try-except here, high probability of failure if incorrect action supplied
-        updated_ids = wf.refresh(fw_id)
-        self._update_wf(wf, updated_ids)
+        with WFLock(self, fw_id):
+            wf = self.get_wf_by_fw_id(fw_id)
+            updated_ids = wf.refresh(fw_id)
+            self._update_wf(wf, updated_ids)
 
 
     def _update_wf(self, wf, updated_ids):
+        # note: must be called within an enclosing WFLock
+
         updated_fws = [wf.id_fw[fid] for fid in updated_ids]
         old_new = self._upsert_fws(updated_fws)
         wf._reassign_ids(old_new)
@@ -893,7 +890,9 @@ class LaunchPad(FWSerializable):
         if not self.workflows.find_one({'nodes': query_node}):
             raise ValueError("BAD QUERY_NODE! {}".format(query_node))
         # redo the links
-        self.workflows.find_and_modify({'nodes': query_node}, wf.to_db_dict())
+        wf = wf.to_db_dict()
+        wf['locked'] = True  # preserve the lock!
+        self.workflows.find_and_modify({'nodes': query_node}, wf)
 
 
     def _steal_launches(self, thief_fw):
