@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 This module contains methods for launching Rockets, both singly and in rapid-fire mode
 """
@@ -62,7 +60,8 @@ def rapidfire(launchpad, fworker=None, m_dir=None, nlaunches=0, max_loops=-1, sl
     num_loops = 0
 
     while num_loops != max_loops:
-        while launchpad.run_exists(fworker):
+        skip_check = False  # this is used to speed operation
+        while skip_check or launchpad.run_exists(fworker):
             os.chdir(curdir)
             launcher_dir = create_datestamp_dir(curdir, l_logger, prefix='launcher_')
             os.chdir(launcher_dir)
@@ -75,7 +74,11 @@ def rapidfire(launchpad, fworker=None, m_dir=None, nlaunches=0, max_loops=-1, sl
                 os.rmdir(launcher_dir)
             if num_launched == nlaunches:
                 break
-            time.sleep(0.15)  # add a small amount of buffer breathing time for DB to refresh, etc.
+            if launchpad.run_exists(fworker):
+                skip_check = True  # don't wait, pull the next FW right away
+            else:
+                time.sleep(0.15)  # add a small amount of buffer breathing time for DB to refresh in case we have a dynamic WF
+                skip_check = False
         if num_launched == nlaunches or nlaunches == 0:
             break
         log_multi(l_logger, 'Sleeping for {} secs'.format(sleep_time))
